@@ -971,13 +971,14 @@ def complete_import(prefix, line, start, end, ctx):
     ..."
     """
     ltoks = line.split()
-    if len(ltoks) == 2 and ltoks[0] == 'from':
+    ntoks = len(ltoks)
+    if ntoks == 2 and ltoks[0] == 'from':
         # completing module to import
         return {'{} '.format(i) for i in complete_module(prefix)}
-    if ltoks[0] == 'import' and start == len('import '):
+    if ntoks > 1 and ltoks[0] == 'import' and start == len('import '):
         # completing module to import
         return complete_module(prefix)
-    if len(ltoks) > 2 and ltoks[0] == 'from' and ltoks[2] == 'import':
+    if ntoks > 2 and ltoks[0] == 'from' and ltoks[2] == 'import':
         # complete thing inside a module
         try:
             mod = importlib.import_module(ltoks[1])
@@ -1126,7 +1127,7 @@ def complete_from_bash(prefix, line, begidx, endidx, ctx):
 
     # From GNU Bash document: The results of the expansion are prefix-matched
     # against the word being completed
-    commprefix = os.path.commonprefix(out)
+    commprefix = os.path.commonprefix(list(out))
     strip_len = 0
     while strip_len < len(prefix):
         if commprefix.startswith(prefix[strip_len:]):
